@@ -1,5 +1,7 @@
 context("Plot axes")
 
+require(grid)
+
 test_that("Axis label formatting is consistent for large values", {
     d <- data.frame(
         x = runif(100, 0, 150000),
@@ -17,3 +19,9 @@ test_that("Axis label formatting is consistent for large values", {
     )
     expect_false(any(grepl("1e+", labs, fixed = TRUE)))
 })
+
+test_that("Axis tick labels don't overlap axis label", {
+    d <- data.frame(x = runif(1e2), y = runif(1e2, 1e5, 2e5), z = sample(LETTERS[1:4], 100, replace = TRUE))
+    inzplot(y ~ x | z, data = d, ylab = "A very long title", transform = list(y = "log"))
+
+})
