@@ -2,7 +2,9 @@ context("Replicate weights")
 
 skip_if_offline()
 
-chis <- iNZightTools::smart_read("https://inzight.nz/testdata/chis2.csv")
+chis <- try(iNZightTools::smart_read("https://inzight.nz/testdata/chis2.csv"), silent = TRUE)
+skip_if(inherits(chis, "try-error"), "Unable to load resource")
+
 dchis <- suppressWarnings(svrepdesign(
     data = chis,
     repweights = "rakedw[1-9]",
